@@ -195,7 +195,8 @@ PAGE-TOKEN is optional and used for pagination."
          (resolution (transient-arg-value "--resolution=" args))
          (version (transient-arg-value "--version=" args))
          (assignee (transient-arg-value "--assignee=" args))
-         (reporter (transient-arg-value "--reporter=" args)))
+         (reporter (transient-arg-value "--reporter=" args))
+         (issue-type (transient-arg-value "--type=" args)))
     (let ((additional-filters
            (list (when myself "assignee = currentUser()")
                  (when current-sprint "sprint in openSprints()")
@@ -203,6 +204,7 @@ PAGE-TOKEN is optional and used for pagination."
                  (when project (concat "project = \"" project "\""))
                  (when resolution (concat "resolution = \"" resolution "\""))
                  (when version (concat "fixversion = \"" version "\""))
+                 (when issue-type (concat "issuetype = \"" issue-type "\""))
                  (when assignee
                    (if (string-match-p "EMPTY" assignee)
                        "assignee = EMPTY"
@@ -274,7 +276,11 @@ PAGE-TOKEN is optional and used for pagination."
     ("v" "Fix Versions" "--version="
      :transient t
      :choices
-     (lambda () (apply #'append (mapcar #'cdr jira-projects-versions))))]
+     (lambda () (apply #'append (mapcar #'cdr jira-projects-versions))))
+    ("t" "Issue Type" "--type="
+     :transient t
+     :choices
+     (lambda () (mapcar #'car jira-issue-types)))]
    ["Arguments Help"
     ("C-x" :info (concat (jira-fmt-set-face "Check " 'italic)
                          "additional options"))
@@ -359,6 +365,8 @@ PAGE-TOKEN is optional and used for pagination."
     (define-key map "C" 'jira-actions-change-issue-menu)
     (define-key map "I" (lambda () (interactive)
                           (jira-detail-show-issue (jira-utils-marked-item))))
+    (define-key map (kbd "RET") (lambda () (interactive)
+                                  (jira-detail-show-issue (jira-utils-marked-item))))
     (define-key map "O" (lambda () (interactive)
                           (jira-actions-open-issue (jira-utils-marked-item))))
     (define-key map "W" 'jira-actions-add-worklog-menu)
